@@ -6,7 +6,7 @@
 #' @export
 #' @import rgdal
 #' @importFrom sp spTransform CRS proj4string
-#' @importFrom rgeos gBuffer gIntersects gUnaryUnion
+#' @importFrom rgeos gBuffer gIntersects gConvexHull
 #' @param aoi an Area of Interest (AOI) as a \code{SpatialPolygons*} object.  
 #' If the AOI is not in the WGS84 geographic coordinate system, it will be 
 #' reprojected to WGS84.
@@ -19,7 +19,7 @@
 calc_gfc_tiles <- function(aoi) {
     aoi <- spTransform(aoi, CRS(proj4string(gfc_tiles)))
     intersecting <- as.logical(gIntersects(gfc_tiles, 
-                                           gUnaryUnion(aoi), 
+                                           gConvexHull(aoi), 
                                            byid=TRUE))
     if (sum(intersecting) == 0) {
         stop('no intersecting GFC tiles found')
